"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthToken = void 0;
// Inspired by https://github.com/shawnjung/homebridge-plugin-dimplex-connex
const luxon_1 = require("luxon");
const axios_1 = __importDefault(require("axios"));
// Pulled from traffic between the devices,
// the app and the services
const APP_ID = 'Ob-Ng-id';
const APP_SECRET = 'Ob-Y1Ngeac9TzrS0fIfDo6u-wAgWDs';
class AuthToken {
    constructor(authInfo) {
        this.authInfo = authInfo;
        this.value = '';
        this.refreshToken = '';
        this.expiryAt = luxon_1.DateTime.local();
        this.client = axios_1.default.create({
            baseURL: 'https://user-field-eu.aylanetworks.com/users',
            timeout: 10000,
            headers: {
                'Content-Type': 'application/json; charset=utf-8',
            },
        });
    }
    get active() {
        return Boolean(this.value);
    }
    get expired() {
        return this.expiryAt < luxon_1.DateTime.local();
    }
    getValue() {
        return this.value;
    }
    async refresh() {
        const body = {
            user: {
                refresh_token: this.refreshToken,
            },
        };
        const headers = {
            Authorization: `auth_token ${this.value}`,
        };
        const { data } = await this.client.post('refresh_token.json', body, { headers });
        this.refreshAttributes(data);
    }
    async init() {
        const body = {
            user: {
                application: {
                    app_id: APP_ID,
                    app_secret: APP_SECRET,
                },
                ...this.authInfo,
            },
        };
        const { data } = await this.client.post('sign_in.json', body);
        this.refreshAttributes(data);
    }
    refreshAttributes(data) {
        this.value = data.access_token;
        this.refreshToken = data.refresh_token;
        this.expiryAt = luxon_1.DateTime.local().plus({ seconds: data.expires_in - 3600 });
    }
}
exports.AuthToken = AuthToken;
//# sourceMappingURL=AuthToken.js.map