import { Device, DeviceProperty } from './types';
export declare class AylaDeviceApiService {
    private authToken;
    private client;
    /**
     * Ayla Networks API class
     *
     * implements AylaNetworks client, connects
     * to the AylaNetwork Services (EU)
     *
     * @param email: your Ayla Networks User username
     * @param password: your Ayla Networks User password
     */
    constructor(email: string, password: string);
    /**
     * Initializes the Api Client
     *
     * @returns an Axios Instance configured for the API endpoint
     */
    private initClient;
    /**
     * Get all Oekoboiler Devices registered with the current user
     *
     * @returns a list of Oekboiler Devices
     */
    getDevices(): Promise<Device[]>;
    /**
     * Get all Oekoboiler Devices registered with the current user
     *
     * @param dsn: The DSN of the Oekoboiler Device.
     *                      Can be found by iterating over the device list
     *                      returned by {@link getDevices()}
     * @returns a list of Oekboiler Device
     *              Properties (see types.ts for the relevant fields)
     */
    getDeviceProperties(dsn: string): Promise<DeviceProperty[]>;
    /**
     * Update a specific device property See {@link Device}, {@link DeviceProperty} for details
     *
     * @param key the property key
     * @param value the property value
     */
    updateDeviceProperty(key: number, value: unknown): Promise<void>;
}
//# sourceMappingURL=AylaDeviceService.d.ts.map