import { Device, OekoboilerDevice } from './types';
import { AylaDeviceApiService } from './AylaDeviceService';
export declare class OekoboilerApi {
    private attributeMap;
    protected aylaNetworkService: AylaDeviceApiService;
    /**
     * Main Oekboiler Api Class
     *
     * implements an Oekoboiler Api client, connects
     * to the AylaNetwork Services (EU) and wraps it into
     *
     *
     * @param userEmail: your Oekoboiler App username
     * @param userPassword: your Oekoboiler App password
     */
    constructor(userEmail: string, userPassword: string);
    /**
     * Get Oekoboiler devices
     *
     * @returns Oekoboiler devices
     */
    getDevices(): Promise<Device[]>;
    /**
     *
     * @param key property key (See {@link Device})
     * @param value
     * @returns
     */
    updateProperty(key: number, value: unknown): Promise<void>;
    /**
     * Get Oekoboiler Data mapped into {@link OekoboilerDevice}
     *
     * @param dsn Boiler DSN
     * @returns an Oekoboiler properties type
     */
    getBoiler(dsn: string): Promise<OekoboilerDevice>;
    /**
     * Properties helper function
     *
     * @remarks
     * Returns key:value pair for a specific, named property
     *
     * @param name device property name
     * @param properties device properties
     * @returns device property key:value pair
     */
    private getPropertyKeyAndValue;
    /**
     * Helper function
     *
     * @remarks
     * folds the raw properties into a Oekboiler device
     *
     * @param properties array of a devices' raw properties
     * @returns an Oekoboiler device
     */
    private getBoilerFromProperties;
}
//# sourceMappingURL=OekoboilerApi.d.ts.map